@@ -16,6 +16,8 @@
 """
 API application handler for Barbican
 """
+import os
+
 import pecan
 
 try:
@@ -36,7 +38,10 @@ from barbican import queue
 CONF = config.CONF
 
 if newrelic_loaded:
-    newrelic.agent.initialize('/etc/newrelic/newrelic.ini')
+    newrelic.agent.initialize(
+        os.environ.get('NEW_RELIC_CONFIG_FILE', '/etc/newrelic/newrelic.ini'),
+        os.environ.get('NEW_RELIC_ENVIRONMENT')
+    )
 
 
 def build_wsgi_app(controller=None, transactional=False):
@@ -57,6 +62,8 @@ def build_wsgi_app(controller=None, transactional=False):
         hooks=request_hooks,
         force_canonical=False
     )
+    # clear the session created in controller initialization     60
+    repositories.clear()
     return wsgi_app
 
 
@@ -71,8 +78,8 @@ def main_app(func):
         config.setup_remote_pydev_debug()
 
         # Initializing the database engine and session factory before the app
-        # starts ensures we don't lose requests due to lazy initialiation of db
-        # connections.
+        # starts ensures we don't lose requests due to lazy initialization of
+        # db connections.
         repositories.setup_database_engine_and_factory()
 
         wsgi_app = func(global_config, **local_conf)
