@@ -16,6 +16,7 @@ from six.moves.urllib import parse
 from barbican import api
 from barbican.api import controllers
 from barbican.api.controllers import acls
+from barbican.api.controllers import secretmeta
 from barbican.common import exception
 from barbican.common import hrefs
 from barbican.common import quota
@@ -72,8 +73,23 @@ class SecretController(controllers.ACLMixin):
     def _lookup(self, sub_resource, *remainder):
         if sub_resource == 'acl':
             return acls.SecretACLsController(self.secret), remainder
+        elif sub_resource == 'metadata':
+            if len(remainder) == 0 or remainder == ('',):
+                return secretmeta.SecretMetadataController(self.secret), \
+                    remainder
+            else:
+                request_method = pecan.request.method
+                allowed_methods = ['GET', 'PUT', 'DELETE']
+
+                if request_method in allowed_methods:
+                    return secretmeta.SecretMetadatumController(self.secret), \
+                        remainder
+                else:
+                    # methods cannot be handled at controller level
+                    pecan.abort(405)
         else:
-            pecan.abort(405)  # only 'acl' as sub-resource is supported
+            # only 'acl' and 'metadata' as sub-resource is supported
+            pecan.abort(405)
 
     @pecan.expose(generic=True)
     def index(self, **kwargs):
@@ -235,7 +251,6 @@ class SecretsController(controllers.ACLMixin):
         # actually does a lookup in the database regardless of the RBAC policy
         # check, the execution only gets here if authentication of the user was
         # previously successful.
-        controllers.assert_is_valid_uuid_from_uri(secret_id)
 
         secret = self.secret_repo.get_secret_by_id(
             entity_id=secret_id, suppress_exception=True)
