@@ -22,9 +22,15 @@ import sys
 sys.path.insert(0, os.getcwd())
 
 from barbican.common import config
+from barbican.model import clean
 from barbican.model.migration import commands
 from oslo_log import log
 
+# Import and configure logging.
+CONF = config.CONF
+log.setup(CONF, 'barbican')
+LOG = log.getLogger(__name__)
+
 
 class DatabaseManager(object):
     """Database Manager class.
@@ -43,6 +49,7 @@ class DatabaseManager(object):
         self.add_upgrade_args()
         self.add_history_args()
         self.add_current_args()
+        self.add_clean_args()
 
     def get_main_parser(self):
         """Create top-level parser and arguments."""
@@ -94,6 +101,33 @@ class DatabaseManager(object):
                                         'revision.')
         create_parser.set_defaults(func=self.current)
 
+    def add_clean_args(self):
+        """Create 'clean' command parser and arguments."""
+        create_parser = self.subparsers.add_parser(
+            'clean',
+            help='Clean up soft deletions in the database')
+        create_parser.add_argument(
+            '--min-days', '-m', type=int, default=90,
+            help='minimum number of days to keep soft deletions. default is'
+                 ' %(default)s days.')
+        create_parser.add_argument('--clean-unassociated-projects', '-p',
+                                   action="store_true",
+                                   help='Remove projects that have no '
+                                        'associated resources.')
+        create_parser.add_argument('--soft-delete-expired-secrets', '-e',
+                                   action="store_true",
+                                   help='Soft delete expired secrets.')
+        create_parser.add_argument('--verbose', '-V', action='store_true',
+                                   help='Show full information about the'
+                                        ' cleanup')
+        create_parser.add_argument('--log-file', '-L',
+                                   default=CONF.log_file,
+                                   type=str,
+                                   help='Set log file location. '
+                                        'Default value for log_file can be '
+                                        'found in barbican.conf')
+        create_parser.set_defaults(func=self.clean)
+
     def revision(self, args):
         """Process the 'revision' Alembic command."""
         commands.generate(autogenerate=args.autogenerate,
@@ -102,6 +136,7 @@ class DatabaseManager(object):
 
     def upgrade(self, args):
         """Process the 'upgrade' Alembic command."""
+        LOG.debug("Performing database schema migration...")
         commands.upgrade(to_version=args.version, sql_url=args.dburl)
 
     def history(self, args):
@@ -110,6 +145,15 @@ class DatabaseManager(object):
     def current(self, args):
         commands.current(args.verbose, sql_url=args.dburl)
 
+    def clean(self, args):
+        clean.clean_command(
+            sql_url=args.dburl,
+            min_num_days=args.min_days,
+            do_clean_unassociated_projects=args.clean_unassociated_projects,
+            do_soft_delete_expired_secrets=args.soft_delete_expired_secrets,
+            verbose=args.verbose,
+            log_file=args.log_file)
+
     def execute(self):
         """Parse the command line arguments."""
         args = self.parser.parse_args()
@@ -125,18 +169,13 @@ def _exception_is_successfull_exit(thrown_exception):
 
 
 def main():
-    # Import and configure logging.
-    CONF = config.CONF
-    log.setup(CONF, 'barbican')
-    LOG = log.getLogger(__name__)
-    LOG.debug("Performing database schema migration...")
 
     try:
         dm = DatabaseManager(CONF)
         dm.execute()
     except Exception as ex:
         if not _exception_is_successfull_exit(ex):
-            LOG.exception('Problem seen trying to execute Alembic commands')
+            LOG.exception('Problem seen trying to run barbican db manage')
             sys.stderr.write("ERROR: {0}\n".format(ex))
             sys.exit(1)
 
