@@ -89,6 +89,18 @@ class MissingMetadataField(BarbicanHTTPException):
     status_code = 400
 
 
+class InvalidMetadataRequest(BarbicanHTTPException):
+    message = u._("Invalid Metadata. Keys and Values must be Strings.")
+    client_message = message
+    status_code = 400
+
+
+class InvalidMetadataKey(BarbicanHTTPException):
+    message = u._("Invalid Key. Key must be URL safe.")
+    client_message = message
+    status_code = 400
+
+
 class InvalidSubjectDN(BarbicanHTTPException):
     message = u._("Invalid subject DN: %(subject_dn)s")
     client_message = message
@@ -412,11 +424,11 @@ class StoredKeyPrivateKeyNotFound(BarbicanException):
                   "key needed for stored key certificate generation.")
 
 
-class InvalidUUIDInURI(BarbicanHTTPException):
-    message = u._("The provided UUID in the URI (%(uuid_string)s) is "
-                  "malformed.")
-    client_message = u._("The provided UUID in the URI is malformed.")
-    status_code = 404
+class ProvidedTransportKeyNotFound(BarbicanHTTPException):
+    message = u._("Provided Transport key %(transport_key_id)s "
+                  "could not be found")
+    client_message = u._("Provided transport key was not found.")
+    status_code = 400
 
 
 class InvalidCAID(BarbicanHTTPException):
