@@ -15,6 +15,7 @@ API JSON validators.
 
 import abc
 import base64
+import re
 
 import jsonschema as schema
 from ldap3.core import exceptions as ldap_exceptions
@@ -180,7 +181,7 @@ class NewSecretValidator(ValidatorBase):
         self.schema = {
             "type": "object",
             "properties": {
-                "name": {"type": "string", "maxLength": 255},
+                "name": {"type": ["string", "null"], "maxLength": 255},
                 "algorithm": {"type": "string", "maxLength": 255},
                 "mode": {"type": "string", "maxLength": 255},
                 "bit_length": {
@@ -200,7 +201,10 @@ class NewSecretValidator(ValidatorBase):
                              secret_store.SecretType.CERTIFICATE,
                              secret_store.SecretType.OPAQUE]
                 },
-                "payload_content_type": {"type": "string", "maxLength": 255},
+                "payload_content_type": {
+                    "type": ["string", "null"],
+                    "maxLength": 255
+                },
                 "payload_content_encoding": {
                     "type": "string",
                     "maxLength": 255,
@@ -242,6 +246,7 @@ class NewSecretValidator(ValidatorBase):
                                                        payload, schema_name)
             json_data['payload'] = payload
         elif 'payload_content_type' in json_data:
+            # parent_schema would be populated if it comes from an order.
             self._assert_validity(parent_schema is not None, schema_name,
                                   u._("payload must be provided when "
                                       "payload_content_type is specified"),
@@ -349,6 +354,104 @@ class NewSecretValidator(ValidatorBase):
         return payload.strip()
 
 
+class NewSecretMetadataValidator(ValidatorBase):
+    """Validate new secret metadata."""
+
+    def __init__(self):
+        self.name = 'SecretMetadata'
+        self.schema = {
+            "type": "object",
+            "$schema": "http://json-schema.org/draft-03/schema",
+            "properties": {
+                "metadata": {"type": "object", "required": True},
+                }
+        }
+
+    def validate(self, json_data, parent_schema=None):
+        """Validate the input JSON for the schema for secret metadata."""
+        schema_name = self._full_name(parent_schema)
+        self._assert_schema_is_valid(json_data, schema_name)
+        return self._extract_metadata(json_data)
+
+    def _extract_metadata(self, json_data):
+        """Extracts and returns the metadata from the JSON data."""
+        metadata = json_data['metadata']
+
+        for key in metadata:
+            # make sure key is a string and url-safe.
+            if not isinstance(key, six.string_types):
+                raise exception.InvalidMetadataRequest()
+            self._check_string_url_safe(key)
+
+            # make sure value is a string.
+            value = metadata[key]
+            if not isinstance(value, six.string_types):
+                raise exception.InvalidMetadataRequest()
+
+            # If key is not lowercase, then change it
+            if not key.islower():
+                del metadata[key]
+                metadata[key.lower()] = value
+
+        return metadata
+
+    def _check_string_url_safe(self, string):
+        """Checks if string can be part of a URL."""
+        if not re.match("^[A-Za-z0-9_-]*$", string):
+            raise exception.InvalidMetadataKey()
+
+
+class NewSecretMetadatumValidator(ValidatorBase):
+    """Validate new secret metadatum."""
+
+    def __init__(self):
+        self.name = 'SecretMetadatum'
+        self.schema = {
+            "type": "object",
+            "$schema": "http://json-schema.org/draft-03/schema",
+            "properties": {
+                "key": {
+                    "type": "string",
+                    "maxLength": 255,
+                    "required": True
+                },
+                "value": {
+                    "type": "string",
+                    "maxLength": 255,
+                    "required": True
+                },
+            },
+            "additionalProperties": False
+        }
+
+    def validate(self, json_data, parent_schema=None):
+        """Validate the input JSON for the schema for secret metadata."""
+        schema_name = self._full_name(parent_schema)
+        self._assert_schema_is_valid(json_data, schema_name)
+
+        key = self._extract_key(json_data)
+        value = self._extract_value(json_data)
+
+        return {"key": key, "value": value}
+
+    def _extract_key(self, json_data):
+        """Extracts and returns the metadata from the JSON data."""
+        key = json_data['key']
+        self._check_string_url_safe(key)
+        key = key.lower()
+        return key
+
+    def _extract_value(self, json_data):
+        """Extracts and returns the metadata from the JSON data."""
+        value = json_data['value']
+        return value
+
+    def _check_string_url_safe(self, string):
+        """Checks if string can be part of a URL."""
+        if not re.match("^[A-Za-z0-9_-]*$", string):
+            raise exception.InvalidMetadataKey()
+
+
 class CACommonHelpersMixin(object):
     def _validate_subject_dn_data(self, subject_dn):
         """Confirm that the subject_dn contains valid data
@@ -569,6 +672,12 @@ class TypeOrderValidator(ValidatorBase, CACommonHelpersMixin):
                                   "for {0} type order").format(order_type),
                               "meta")
 
+        self._assert_validity(meta.get('bit_length'),
+                              schema_name,
+                              u._("'bit_length' is required field "
+                                  "for {0} type order").format(order_type),
+                              "meta")
+
         self._validate_bit_length(meta, schema_name)
 
     def _extract_expiration(self, json_data, schema_name):
@@ -590,15 +699,7 @@ class TypeOrderValidator(ValidatorBase, CACommonHelpersMixin):
 
     def _validate_bit_length(self, meta, schema_name):
 
-        bit_length = int(meta.get('bit_length', 0))
-        if bit_length <= 0:
-            raise exception.UnsupportedField(field="bit_length",
-                                             schema=schema_name,
-                                             reason=u._("Must have "
-                                                        "non-zero positive"
-                                                        " bit_length to"
-                                                        " generate secret"
-                                                        ))
+        bit_length = int(meta.get('bit_length'))
         if bit_length % 8 != 0:
             raise exception.UnsupportedField(field="bit_length",
                                              schema=schema_name,
@@ -682,7 +783,7 @@ class ContainerValidator(ValidatorBase):
         self.schema = {
             "type": "object",
             "properties": {
-                "name": {"type": ["string", "null"]},
+                "name": {"type": ["string", "null"], "maxLength": 255},
                 "type": {
                     "type": "string",
                     # TODO(hgedikli): move this to a common location
@@ -694,6 +795,9 @@ class ContainerValidator(ValidatorBase):
                         "type": "object",
                         "required": ["secret_ref"],
                         "properties": {
+                            "name": {
+                                "type": ["string", "null"], "maxLength": 255
+                            },
                             "secret_ref": {"type": "string", "minLength": 1}
                         }
                     }
