@@ -63,7 +63,8 @@ dogtag_plugin_opts = [
     cfg.StrOpt('nss_db_path',
                help=u._('Path to the NSS certificate database')),
     cfg.StrOpt('nss_password',
-               help=u._('Password for the NSS certificate databases')),
+               help=u._('Password for the NSS certificate databases'),
+               secret=True),
     cfg.StrOpt('simple_cmc_profile',
                help=u._('Profile for simple CMC requests')),
     cfg.StrOpt('auto_approved_profiles',
