@@ -64,9 +64,16 @@ class SecretStorePluginNotFound(exception.BarbicanHTTPException):
         super(SecretStorePluginNotFound, self).__init__(message)
 
 
-class SecretStoreSupportedPluginNotFound(exception.BarbicanException):
+class SecretStoreSupportedPluginNotFound(exception.BarbicanHTTPException):
     """Raised if no plugins are found that support the requested operation."""
-    message = u._("Secret store plugin not found for requested operation.")
+
+    client_message = u._("Secret store supported plugin not found.")
+    status_code = 400
+
+    def __init__(self, plugin_name=None):
+        message = u._("Secret store plugin not found for requested operation.")
+        super(SecretStoreSupportedPluginNotFound, self).__init__(
+            message)
 
 
 class SecretContentTypeNotSupportedException(exception.BarbicanHTTPException):
@@ -477,7 +484,7 @@ class SecretStoreBase(object):
 
 def _enforce_extensions_configured(plugin_related_function):
     def _check_plugins_configured(self, *args, **kwargs):
-        if len(self.extensions) < 1:
+        if not self.extensions:
             raise SecretStorePluginsNotConfigured()
         return plugin_related_function(self, *args, **kwargs)
     return _check_plugins_configured
