@@ -44,12 +44,11 @@ CONF = config.new_config()
 kmip_opt_group = cfg.OptGroup(name='kmip_plugin', title='KMIP Plugin')
 kmip_opts = [
     cfg.StrOpt('username',
-               default=None,
                help=u._('Username for authenticating with KMIP server')
                ),
     cfg.StrOpt('password',
-               default=None,
-               help=u._('Password for authenticating with KMIP server')
+               help=u._('Password for authenticating with KMIP server'),
+               secret=True,
                ),
     cfg.StrOpt('host',
                default='localhost',
@@ -64,16 +63,13 @@ kmip_opts = [
                help=u._('SSL version, maps to the module ssl\'s constants'),
                ),
     cfg.StrOpt('ca_certs',
-               default=None,
                help=u._('File path to concatenated "certification authority" '
                         'certificates'),
                ),
     cfg.StrOpt('certfile',
-               default=None,
                help=u._('File path to local client certificate'),
                ),
     cfg.StrOpt('keyfile',
-               default=None,
                help=u._('File path to local client certificate keyfile'),
                ),
     cfg.BoolOpt('pkcs1_only',
@@ -255,7 +251,7 @@ class KMIPSecretStore(ss.SecretStoreBase):
                     "'generate_symmetric_key' method").format(
                         algorithm=key_spec.alg))
 
-        algorithm = self._get_kmip_algorithm(key_spec.alg)
+        algorithm = self._get_kmip_algorithm(key_spec.alg.lower())
         try:
             with self.client:
                 LOG.debug("Opened connection to KMIP client for secret " +
@@ -295,7 +291,7 @@ class KMIPSecretStore(ss.SecretStoreBase):
                 u._('KMIP plugin does not currently support protecting the '
                     'private key with a passphrase'))
 
-        algorithm = self._get_kmip_algorithm(key_spec.alg)
+        algorithm = self._get_kmip_algorithm(key_spec.alg.lower())
         length = key_spec.bit_length
 
         try:
