@@ -18,12 +18,10 @@ This test module focuses on typical-flow business logic tests with the API
 resource classes. For RBAC tests of these classes, see the
 'resources_policy_test.py' module.
 """
-import logging
 import mimetypes
 
 import mock
 import pecan
-import six
 from testtools import testcase
 import webtest
 
@@ -38,9 +36,6 @@ from barbican.model import models
 from barbican.tests import utils
 
 
-LOG = logging.getLogger(__name__)
-
-
 def get_barbican_env(external_project_id):
     """Create and return a barbican.context for use with the RBAC decorator
 
@@ -381,12 +376,12 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
         self.secret_repo.get_secret_by_id.assert_called_once_with(
             entity_id=self.secret.id,
             suppress_exception=True)
-        self.assertEqual(resp.status_int, 200)
+        self.assertEqual(200, resp.status_int)
 
         self.assertNotIn('content_encodings', resp.namespace)
         self.assertIn('content_types', resp.namespace)
         self.assertIn(self.datum.content_type,
-                      six.itervalues(resp.namespace['content_types']))
+                      resp.namespace['content_types'].values())
         self.assertNotIn('mime_type', resp.namespace)
 
     @testcase.attr('deprecated')
@@ -404,9 +399,9 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
         self.secret_repo.get_secret_by_id.assert_called_once_with(
             entity_id=self.secret.id,
             suppress_exception=True)
-        self.assertEqual(resp.status_int, 200)
+        self.assertEqual(200, resp.status_int)
 
-        self.assertEqual(resp.body, data)
+        self.assertEqual(data, resp.body)
         mock_get_secret.assert_called_once_with(
             'text/plain',
             self.secret,
@@ -431,9 +426,9 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
         self.secret_repo.get_secret_by_id.assert_called_once_with(
             entity_id=self.secret.id,
             suppress_exception=True)
-        self.assertEqual(resp.status_int, 200)
+        self.assertEqual(200, resp.status_int)
 
-        self.assertEqual(resp.body, data)
+        self.assertEqual(data, resp.body)
         mock_get_secret.assert_called_once_with(
             'text/plain',
             self.secret,
@@ -460,9 +455,9 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
         self.secret_repo.get_secret_by_id.assert_called_once_with(
             entity_id=self.secret.id,
             suppress_exception=True)
-        self.assertEqual(resp.status_int, 200)
+        self.assertEqual(200, resp.status_int)
 
-        self.assertEqual(resp.body, data)
+        self.assertEqual(data, resp.body)
         mock_get_secret.assert_called_once_with(
             'text/plain',
             self.secret,
@@ -488,7 +483,7 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
         self.secret_repo.get_secret_by_id.assert_called_once_with(
             entity_id=self.secret.id,
             suppress_exception=True)
-        self.assertEqual(resp.status_int, 400)
+        self.assertEqual(400, resp.status_int)
 
     @testcase.attr('deprecated')
     @mock.patch('barbican.plugin.resources.get_secret')
@@ -508,7 +503,7 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
         self.secret_repo.get_secret_by_id.assert_called_once_with(
             entity_id=self.secret.id,
             suppress_exception=True)
-        self.assertEqual(resp.status_int, 400)
+        self.assertEqual(400, resp.status_int)
 
     @mock.patch('barbican.plugin.resources.get_transport_key_id_for_retrieval')
     def test_should_get_secret_meta_for_binary(self, mock_get_transport_key):
@@ -528,12 +523,12 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
             entity_id=self.secret.id,
             suppress_exception=True)
 
-        self.assertEqual(resp.status_int, 200)
+        self.assertEqual(200, resp.status_int)
 
         self.assertIsNotNone(resp.namespace)
         self.assertIn('content_types', resp.namespace)
         self.assertIn(self.datum.content_type,
-                      six.itervalues(resp.namespace['content_types']))
+                      resp.namespace['content_types'].values())
 
     @mock.patch('barbican.plugin.resources.get_transport_key_id_for_retrieval')
     def test_should_get_secret_meta_for_binary_with_tkey(
@@ -555,17 +550,16 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
             entity_id=self.secret.id,
             suppress_exception=True)
 
-        self.assertEqual(resp.status_int, 200)
+        self.assertEqual(200, resp.status_int)
 
         self.assertIsNotNone(resp.namespace)
         self.assertIn('content_types', resp.namespace)
         self.assertIn(self.datum.content_type,
-                      six.itervalues(resp.namespace['content_types']))
+                      resp.namespace['content_types'].values())
         self.assertIn('transport_key_ref', resp.namespace)
         self.assertEqual(
-            resp.namespace['transport_key_ref'],
-            hrefs.convert_transport_key_to_href(
-                self.transport_key_id)
+            hrefs.convert_transport_key_to_href(self.transport_key_id),
+            resp.namespace['transport_key_ref']
         )
 
     @testcase.attr('deprecated')
@@ -586,7 +580,7 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
             }
         )
 
-        self.assertEqual(resp.body, data)
+        self.assertEqual(data, resp.body)
 
         mock_get_secret.assert_called_once_with(
             'application/octet-stream',
@@ -608,7 +602,7 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
             headers={'Accept': 'text/plain', 'Content-Type': 'text/plain'},
         )
 
-        self.assertEqual(resp.status_int, 204)
+        self.assertEqual(204, resp.status_int)
 
         mock_store_secret.assert_called_once_with(
             unencrypted_raw='plain text',
@@ -634,7 +628,7 @@ class WhenGettingPuttingOrDeletingSecretUsingSecretResource(FunctionalTest):
             },
         )
 
-        self.assertEqual(resp.status_int, 204)
+        self.assertEqual(204, resp.status_int)
 
         mock_store_secret.assert_called_once_with(
             unencrypted_raw='plain text',
@@ -815,7 +809,7 @@ class WhenCreatingConsumersUsingConsumersResource(FunctionalTest):
             '/containers/{0}/consumers/'.format(self.container.id),
             self.consumer_ref
         )
-        self.assertEqual(resp.status_int, 200)
+        self.assertEqual(200, resp.status_int)
         self.assertNotIn(self.external_project_id, resp.headers['Location'])
 
         args, kwargs = self.consumer_repo.create_or_update_from.call_args
@@ -828,7 +822,7 @@ class WhenCreatingConsumersUsingConsumersResource(FunctionalTest):
             '',
             expect_errors=True
         )
-        self.assertEqual(resp.status_int, 415)
+        self.assertEqual(415, resp.status_int)
 
     def test_should_404_consumer_bad_container_id(self):
         self.container_repo.get.side_effect = excep.NotFound()
@@ -837,7 +831,7 @@ class WhenCreatingConsumersUsingConsumersResource(FunctionalTest):
             self.consumer_ref, expect_errors=True
         )
         self.container_repo.get.side_effect = None
-        self.assertEqual(resp.status_int, 404)
+        self.assertEqual(404, resp.status_int)
 
     def test_should_raise_exception_when_container_ref_doesnt_exist(self):
         self.container_repo.get.return_value = None
@@ -846,7 +840,7 @@ class WhenCreatingConsumersUsingConsumersResource(FunctionalTest):
             self.consumer_ref,
             expect_errors=True
         )
-        self.assertEqual(resp.status_int, 404)
+        self.assertEqual(404, resp.status_int)
 
 
 class WhenGettingOrDeletingConsumersUsingConsumerResource(FunctionalTest):
@@ -922,7 +916,7 @@ class WhenGettingOrDeletingConsumersUsingConsumerResource(FunctionalTest):
         resp = self.app.get('/containers/{0}/consumers/'.format(
             self.container.id
         ))
-        self.assertEqual(resp.status_int, 200)
+        self.assertEqual(200, resp.status_int)
 
         self.consumer_repo.get_by_container_id.assert_called_once_with(
             self.container.id,
@@ -940,28 +934,28 @@ class WhenGettingOrDeletingConsumersUsingConsumerResource(FunctionalTest):
             'bad_id'
         ), expect_errors=True)
         self.container_repo.get.side_effect = None
-        self.assertEqual(resp.status_int, 404)
+        self.assertEqual(404, resp.status_int)
 
     def test_should_get_consumer_by_id(self):
         self.consumer_repo.get.return_value = self.consumer
         resp = self.app.get('/containers/{0}/consumers/{1}/'.format(
             self.container.id, self.consumer.id
         ))
-        self.assertEqual(resp.status_int, 200)
+        self.assertEqual(200, resp.status_int)
 
     def test_should_404_with_bad_consumer_id(self):
         self.consumer_repo.get.return_value = None
         resp = self.app.get('/containers/{0}/consumers/{1}/'.format(
             self.container.id, 'bad_id'
         ), expect_errors=True)
-        self.assertEqual(resp.status_int, 404)
+        self.assertEqual(404, resp.status_int)
 
     def test_should_get_no_consumers(self):
         self.consumer_repo.get_by_container_id.return_value = ([], 0, 0, 0)
         resp = self.app.get('/containers/{0}/consumers/'.format(
             self.container.id
         ))
-        self.assertEqual(resp.status_int, 200)
+        self.assertEqual(200, resp.status_int)
 
     def test_should_delete_consumer(self):
         self.app.delete_json('/containers/{0}/consumers/'.format(
@@ -977,7 +971,7 @@ class WhenGettingOrDeletingConsumersUsingConsumerResource(FunctionalTest):
             '',
             expect_errors=True
         )
-        self.assertEqual(resp.status_int, 415)
+        self.assertEqual(415, resp.status_int)
 
     def test_should_404_on_delete_when_consumer_not_found(self):
         old_return = self.consumer_repo.get_by_values.return_value
@@ -986,9 +980,9 @@ class WhenGettingOrDeletingConsumersUsingConsumerResource(FunctionalTest):
             self.container.id
         ), self.consumer_ref, expect_errors=True)
         self.consumer_repo.get_by_values.return_value = old_return
-        self.assertEqual(resp.status_int, 404)
+        self.assertEqual(404, resp.status_int)
         # Error response should have json content type
-        self.assertEqual(resp.content_type, "application/json")
+        self.assertEqual("application/json", resp.content_type)
 
     def test_should_404_on_delete_when_consumer_not_found_later(self):
         self.consumer_repo.delete_entity_by_id.side_effect = excep.NotFound()
@@ -996,9 +990,9 @@ class WhenGettingOrDeletingConsumersUsingConsumerResource(FunctionalTest):
             self.container.id
         ), self.consumer_ref, expect_errors=True)
         self.consumer_repo.delete_entity_by_id.side_effect = None
-        self.assertEqual(resp.status_int, 404)
+        self.assertEqual(404, resp.status_int)
         # Error response should have json content type
-        self.assertEqual(resp.content_type, "application/json")
+        self.assertEqual("application/json", resp.content_type)
 
     def test_should_delete_consumers_on_container_delete(self):
         consumers = [self.consumer, self.consumer2]
@@ -1008,7 +1002,7 @@ class WhenGettingOrDeletingConsumersUsingConsumerResource(FunctionalTest):
         resp = self.app.delete(
             '/containers/{0}/'.format(self.container.id)
         )
-        self.assertEqual(resp.status_int, 204)
+        self.assertEqual(204, resp.status_int)
 
         # Verify consumers were deleted
         calls = []
@@ -1027,7 +1021,7 @@ class WhenGettingOrDeletingConsumersUsingConsumerResource(FunctionalTest):
         resp = self.app.delete(
             '/containers/{0}/'.format(self.container.id)
         )
-        self.assertEqual(resp.status_int, 204)
+        self.assertEqual(204, resp.status_int)
 
         # Verify consumers were deleted
         calls = []
@@ -1132,7 +1126,7 @@ class WhenPerformingUnallowedOperationsOnConsumers(FunctionalTest):
             self.consumer_ref,
             expect_errors=True
         )
-        self.assertEqual(resp.status_int, 405)
+        self.assertEqual(405, resp.status_int)
 
     def test_should_not_allow_post_on_consumer_by_id(self):
         self.consumer_repo.get.return_value = self.consumer
@@ -1142,7 +1136,7 @@ class WhenPerformingUnallowedOperationsOnConsumers(FunctionalTest):
             self.consumer_ref,
             expect_errors=True
         )
-        self.assertEqual(resp.status_int, 405)
+        self.assertEqual(405, resp.status_int)
 
     def test_should_not_allow_put_on_consumer_by_id(self):
         self.consumer_repo.get.return_value = self.consumer
@@ -1152,7 +1146,7 @@ class WhenPerformingUnallowedOperationsOnConsumers(FunctionalTest):
             self.consumer_ref,
             expect_errors=True
         )
-        self.assertEqual(resp.status_int, 405)
+        self.assertEqual(405, resp.status_int)
 
     def test_should_not_allow_delete_on_consumer_by_id(self):
         self.consumer_repo.get.return_value = self.consumer
@@ -1161,4 +1155,4 @@ class WhenPerformingUnallowedOperationsOnConsumers(FunctionalTest):
                                                     self.consumer.id),
             expect_errors=True
         )
-        self.assertEqual(resp.status_int, 405)
+        self.assertEqual(405, resp.status_int)
