@@ -13,8 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import mock
+from oslo_config import cfg
 import six
 
+from barbican.common import config
 from barbican.common import utils
 from barbican.tests import utils as test_utils
 
@@ -31,24 +33,22 @@ class WhenTestingHostnameForRefsGetter(test_utils.BaseTestCase):
 
         self._old_host = utils.CONF.host_href
         self._old_version = utils.API_VERSION
-        utils.CONF.host_href = self.host
+        utils.CONF.set_override('host_href', self.host, enforce_type=True)
         utils.API_VERSION = self.version
 
     def tearDown(self):
         super(WhenTestingHostnameForRefsGetter, self).tearDown()
-        utils.CONF.host_href = self._old_host
+        utils.CONF.clear_override('host_href')
         utils.API_VERSION = self._old_version
 
     def test_hostname_for_refs(self):
         uri = utils.hostname_for_refs(resource=self.resource)
-        self.assertEqual(uri, "{0}/{1}/{2}".format(self.host,
-                                                   self.version,
-                                                   self.resource))
+        self.assertEqual("{0}/{1}/{2}".format(self.host, self.version,
+                                              self.resource), uri)
 
     def test_hostname_for_refs_no_resource(self):
         uri = utils.hostname_for_refs()
-        self.assertEqual(uri, "{0}/{1}".format(self.host,
-                                               self.version))
+        self.assertEqual("{0}/{1}".format(self.host, self.version), uri)
 
 
 class WhenTestingAcceptEncodingGetter(test_utils.BaseTestCase):
@@ -62,7 +62,7 @@ class WhenTestingAcceptEncodingGetter(test_utils.BaseTestCase):
         self.req.get_header.return_value = '*'
         ae = utils.get_accepted_encodings(self.req)
         self.req.get_header.assert_called_once_with('Accept-Encoding')
-        self.assertEqual(ae, ['*'])
+        self.assertEqual(['*'], ae)
 
     def test_returns_none_for_empty_encoding(self):
         self.req.get_header.return_value = None
@@ -72,17 +72,17 @@ class WhenTestingAcceptEncodingGetter(test_utils.BaseTestCase):
     def test_parses_single_accept_with_quality_value(self):
         self.req.get_header.return_value = 'base64;q=0.7'
         ae = utils.get_accepted_encodings(self.req)
-        self.assertEqual(ae, ['base64'])
+        self.assertEqual(['base64'], ae)
 
     def test_parses_more_than_one_encoding(self):
         self.req.get_header.return_value = 'base64, gzip'
         ae = utils.get_accepted_encodings(self.req)
-        self.assertEqual(ae, ['base64', 'gzip'])
+        self.assertEqual(['base64', 'gzip'], ae)
 
     def test_can_sort_by_quality_value(self):
         self.req.get_header.return_value = 'base64;q=0.5, gzip;q=0.6, compress'
         ae = utils.get_accepted_encodings(self.req)
-        self.assertEqual(ae, ['compress', 'gzip', 'base64'])
+        self.assertEqual(['compress', 'gzip', 'base64'], ae)
 
     def test_returns_none_on_invalid_quality_type(self):
         self.req.get_header.return_value = 'base64;q=three'
@@ -102,7 +102,7 @@ class WhenTestingAcceptEncodingGetter(test_utils.BaseTestCase):
     def test_ignores_encoding_with_zero_quality_value(self):
         self.req.get_header.return_value = 'base64;q=0.5, gzip;q=0.0, compress'
         ae = utils.get_accepted_encodings(self.req)
-        self.assertEqual(ae, ['compress', 'base64'])
+        self.assertEqual(['compress', 'base64'], ae)
 
 
 class WhenTestingGenerateFullClassnameForInstance(test_utils.BaseTestCase):
@@ -130,3 +130,32 @@ class WhenTestingGenerateFullClassnameForInstance(test_utils.BaseTestCase):
         self.instance.__class__.__module__ = 'dummy'
         name = utils.generate_fullname_for(self.instance)
         self.assertEqual('dummy.DummyClassForTesting', name)
+
+
+class TestConfigValues(test_utils.BaseTestCase):
+
+    def setUp(self):
+        super(TestConfigValues, self).setUp()
+        self.barbican_config = config.CONF
+        self.oslo_config = cfg.CONF
+
+    def test_barbican_conf_values_made_visible_to_oslo_conf(self):
+        """In this, checking oslo CONF values are same as barbican config
+
+        This tests shows that after the change values referenced via
+        oslo_config.cfg.CONF value are same as
+        barbican.common.config.CONF.
+        """
+
+        # Checking that 'admin_role' value referred via
+        # barbican.common.config.CONF is same as oslo_config.cfg.CONF
+        self.assertEqual('admin', self.barbican_config._get('admin_role'))
+        self.assertEqual('admin', self.barbican_config.admin_role)
+
+        self.assertEqual('admin', self.oslo_config._get('admin_role'))
+        self.assertEqual('admin', self.oslo_config.admin_role)
+
+        # No error in getting 'project' value from both config reading
+        # mechanism
+        self.assertEqual('barbican', self.barbican_config.project)
+        self.assertEqual('barbican', self.oslo_config.project)
