@@ -172,8 +172,8 @@ class WhenTestingDogtagKRAPlugin(utils.BaseTestCase):
         result = self.plugin.get_secret(sstore.SecretType.PRIVATE,
                                         secret_metadata)
 
-        self.assertEqual(result.secret,
-                         test_key.exportKey('PEM').encode('utf-8'))
+        self.assertEqual(test_key.exportKey('PEM').encode('utf-8'),
+                         result.secret)
 
     def test_get_public_key(self):
         test_public_key = RSA.generate(2048).publickey()
@@ -189,8 +189,8 @@ class WhenTestingDogtagKRAPlugin(utils.BaseTestCase):
         result = self.plugin.get_secret(sstore.SecretType.PUBLIC,
                                         secret_metadata)
 
-        self.assertEqual(result.secret,
-                         test_public_key.exportKey('PEM').encode('utf-8'))
+        self.assertEqual(test_public_key.exportKey('PEM').encode('utf-8'),
+                         result.secret)
 
     def test_store_passphrase_for_using_in_private_key_retrieval(self):
 
@@ -207,9 +207,10 @@ class WhenTestingDogtagKRAPlugin(utils.BaseTestCase):
         asym_key_DTO = self.plugin.generate_asymmetric_key(key_spec)
 
         self.assertEqual(
+            '1',
             asym_key_DTO.private_key_meta[
-                dogtag_import.DogtagKRAPlugin.PASSPHRASE_KEY_ID],
-            '1')
+                dogtag_import.DogtagKRAPlugin.PASSPHRASE_KEY_ID]
+        )
 
         self.keyclient_mock.generate_asymmetric_key.assert_called_once_with(
             mock.ANY,
@@ -337,16 +338,16 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
             self.approved_profile_id,
             order_meta)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.CERTIFICATE_GENERATED,
+        self.assertEqual(cm.CertificateStatus.CERTIFICATE_GENERATED,
+                         result_dto.status,
                          "result_dto status incorrect")
 
         self.assertEqual(base64.b64encode(keys.get_certificate_pem()),
                          result_dto.certificate)
 
         self.assertEqual(
-            plugin_meta.get(dogtag_import.DogtagCAPlugin.REQUEST_ID),
-            self.request_id_mock
+            self.request_id_mock,
+            plugin_meta.get(dogtag_import.DogtagCAPlugin.REQUEST_ID)
         )
 
     def _process_non_approved_profile_request(self, order_meta, plugin_meta,
@@ -383,13 +384,13 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
         self.certclient_mock.submit_enrollment_request.assert_called_once_with(
             enrollment_result)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.WAITING_FOR_CA,
+        self.assertEqual(cm.CertificateStatus.WAITING_FOR_CA,
+                         result_dto.status,
                          "result_dto status incorrect")
 
         self.assertEqual(
-            plugin_meta.get(dogtag_import.DogtagCAPlugin.REQUEST_ID),
-            self.request_id_mock
+            self.request_id_mock,
+            plugin_meta.get(dogtag_import.DogtagCAPlugin.REQUEST_ID)
         )
 
     def test_issue_simple_cmc_request(self):
@@ -492,8 +493,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
             self.approved_profile_id,
             order_meta)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.CLIENT_DATA_ISSUE_SEEN,
+        self.assertEqual(cm.CertificateStatus.CLIENT_DATA_ISSUE_SEEN,
+                         result_dto.status,
                          "result_dto status incorrect")
 
         self.assertEqual(
@@ -518,13 +519,13 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
             self.approved_profile_id,
             order_meta)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.REQUEST_CANCELED,
+        self.assertEqual(cm.CertificateStatus.REQUEST_CANCELED,
+                         result_dto.status,
                          "result_dto status incorrect")
 
         self.assertEqual(
+            self.request_id_mock,
             plugin_meta.get(dogtag_import.DogtagCAPlugin.REQUEST_ID),
-            self.request_id_mock
         )
 
     def test_issue_return_waiting_with_request_pending(self):
@@ -532,7 +533,6 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
             dogtag_import.DogtagCAPlugin.PROFILE_ID: "otherProfile",
             'cert_request': base64.b64encode(keys.get_csr_pem())}
         plugin_meta = {}
-
         inputs = {
             'cert_request': keys.get_csr_pem(),
             dogtag_import.DogtagCAPlugin.PROFILE_ID: "otherProfile"
@@ -560,8 +560,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
         )
 
         self.assertEqual(
-            plugin_meta.get(dogtag_import.DogtagCAPlugin.REQUEST_ID),
-            self.request_id_mock
+            self.request_id_mock,
+            plugin_meta.get(dogtag_import.DogtagCAPlugin.REQUEST_ID)
         )
 
     def test_issue_raises_error_request_unknown_status(self):
@@ -585,8 +585,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
         )
 
         self.assertEqual(
-            plugin_meta.get(dogtag_import.DogtagCAPlugin.REQUEST_ID),
-            self.request_id_mock
+            self.request_id_mock,
+            plugin_meta.get(dogtag_import.DogtagCAPlugin.REQUEST_ID)
         )
 
     def test_issue_return_client_error_bad_request_exception(self):
@@ -604,8 +604,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
             self.approved_profile_id,
             order_meta)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.CLIENT_DATA_ISSUE_SEEN,
+        self.assertEqual(cm.CertificateStatus.CLIENT_DATA_ISSUE_SEEN,
+                         result_dto.status,
                          "result_dto status incorrect")
 
     def test_issue_raises_error_pki_exception(self):
@@ -640,8 +640,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
             self.approved_profile_id,
             order_meta)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.CA_UNAVAILABLE_FOR_REQUEST,
+        self.assertEqual(cm.CertificateStatus.CA_UNAVAILABLE_FOR_REQUEST,
+                         result_dto.status,
                          "result_dto status incorrect")
 
     def test_cancel_request(self):
@@ -658,8 +658,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
             self.request_id_mock,
             self.review_response)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.REQUEST_CANCELED,
+        self.assertEqual(cm.CertificateStatus.REQUEST_CANCELED,
+                         result_dto.status,
                          "result_dto_status incorrect")
 
     def test_cancel_no_request_found(self):
@@ -675,8 +675,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
         self.certclient_mock.review_request.assert_called_once_with(
             self.request_id_mock)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.CLIENT_DATA_ISSUE_SEEN,
+        self.assertEqual(cm.CertificateStatus.CLIENT_DATA_ISSUE_SEEN,
+                         result_dto.status,
                          "result_dto_status incorrect")
 
     def test_cancel_conflicting_operation(self):
@@ -694,8 +694,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
             self.request_id_mock,
             self.review_response)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.INVALID_OPERATION,
+        self.assertEqual(cm.CertificateStatus.INVALID_OPERATION,
+                         result_dto.status,
                          "result_dto_status incorrect")
 
     def test_cancel_ca_unavailable(self):
@@ -708,8 +708,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
         result_dto = self.plugin.cancel_certificate_request(
             self.order_id, order_meta, plugin_meta, self.barbican_meta_dto)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.CA_UNAVAILABLE_FOR_REQUEST,
+        self.assertEqual(cm.CertificateStatus.CA_UNAVAILABLE_FOR_REQUEST,
+                         result_dto.status,
                          "result_dto_status incorrect")
 
     def test_cancel_raise_error_no_request_id(self):
@@ -741,8 +741,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
         self.certclient_mock.get_cert.assert_called_once_with(
             self.cert_id_mock)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.CERTIFICATE_GENERATED,
+        self.assertEqual(cm.CertificateStatus.CERTIFICATE_GENERATED,
+                         result_dto.status,
                          "result_dto_status incorrect")
 
         self.assertEqual(keys.get_certificate_pem(),
@@ -774,12 +774,11 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
         self.certclient_mock.get_request.assert_called_once_with(
             self.request_id_mock)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.CLIENT_DATA_ISSUE_SEEN,
+        self.assertEqual(cm.CertificateStatus.CLIENT_DATA_ISSUE_SEEN,
+                         result_dto.status,
                          "result_dto_status incorrect")
 
-        self.assertEqual(result_dto.certificate,
-                         None)
+        self.assertIsNone(result_dto.certificate)
 
     def test_check_status_canceled(self):
         order_meta = mock.ANY
@@ -794,12 +793,11 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
         self.certclient_mock.get_request.assert_called_once_with(
             self.request_id_mock)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.REQUEST_CANCELED,
+        self.assertEqual(cm.CertificateStatus.REQUEST_CANCELED,
+                         result_dto.status,
                          "result_dto_status incorrect")
 
-        self.assertEqual(result_dto.certificate,
-                         None)
+        self.assertIsNone(result_dto.certificate)
 
     def test_check_status_pending(self):
         order_meta = mock.ANY
@@ -814,12 +812,11 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
         self.certclient_mock.get_request.assert_called_once_with(
             self.request_id_mock)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.WAITING_FOR_CA,
+        self.assertEqual(cm.CertificateStatus.WAITING_FOR_CA,
+                         result_dto.status,
                          "result_dto_status incorrect")
 
-        self.assertEqual(result_dto.certificate,
-                         None)
+        self.assertIsNone(result_dto.certificate)
 
     def test_check_status_raises_error_complete_no_cert(self):
         order_meta = mock.ANY
@@ -876,8 +873,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
         self.certclient_mock.review_request.assert_called_once_with(
             self.request_id_mock)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.CLIENT_DATA_ISSUE_SEEN,
+        self.assertEqual(cm.CertificateStatus.CLIENT_DATA_ISSUE_SEEN,
+                         result_dto.status,
                          "result_dto_status incorrect")
 
     def test_modify_conflicting_operation(self):
@@ -895,8 +892,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
             self.request_id_mock,
             self.review_response)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.INVALID_OPERATION,
+        self.assertEqual(cm.CertificateStatus.INVALID_OPERATION,
+                         result_dto.status,
                          "result_dto_status incorrect")
 
     def test_modify_ca_unavailable(self):
@@ -909,8 +906,8 @@ class WhenTestingDogtagCAPlugin(utils.BaseTestCase):
         result_dto = self.plugin.modify_certificate_request(
             self.order_id, order_meta, plugin_meta, self.barbican_meta_dto)
 
-        self.assertEqual(result_dto.status,
-                         cm.CertificateStatus.CA_UNAVAILABLE_FOR_REQUEST,
+        self.assertEqual(cm.CertificateStatus.CA_UNAVAILABLE_FOR_REQUEST,
+                         result_dto.status,
                          "result_dto_status incorrect")
 
     def test_modify_raise_error_no_request_id(self):
