@@ -601,9 +601,6 @@ class WhenTestingKMIPSecretStore(utils.BaseTestCase):
         proxy = self.secret_store.client.proxy
         register_call_args, _ = proxy.register.call_args
         actual_secret = register_call_args[2]
-        self.assertEqual(
-            enums.CertificateTypeEnum.X_509.value,
-            actual_secret.certificate_type.value)
         self.assertEqual(
             keys.get_certificate_der(),
             actual_secret.certificate_value.value)
@@ -820,7 +817,7 @@ class WhenTestingKMIPSecretStore(utils.BaseTestCase):
 
     def test_delete_with_null_metadata_values(self):
         metadata = {kss.KMIPSecretStore.KEY_UUID: None}
-        self.assertEqual(None, self.secret_store.delete_secret(metadata))
+        self.assertIsNone(self.secret_store.delete_secret(metadata))
 
     def test_delete_secret_assert_called(self):
         metadata = {kss.KMIPSecretStore.KEY_UUID: self.symmetric_key_uuid}
@@ -831,7 +828,7 @@ class WhenTestingKMIPSecretStore(utils.BaseTestCase):
     def test_delete_secret_return_value(self):
         metadata = {kss.KMIPSecretStore.KEY_UUID: self.symmetric_key_uuid}
         return_value = self.secret_store.delete_secret(metadata)
-        self.assertEqual(None, return_value)
+        self.assertIsNone(return_value)
 
     def test_delete_secret_server_error_occurs(self):
         self.secret_store.client.proxy.destroy = mock.MagicMock(
@@ -857,9 +854,6 @@ class WhenTestingKMIPSecretStore(utils.BaseTestCase):
     def test_credential(self):
         actual_credential = self.secret_store.credential
 
-        self.assertEqual(
-            enums.CredentialType.USERNAME_AND_PASSWORD.value,
-            actual_credential.credential_type.value)
         self.assertEqual(
             self.expected_username,
             actual_credential.credential_value.username.value)
@@ -917,4 +911,4 @@ class WhenTestingKMIPSecretStore(utils.BaseTestCase):
             CONF = kss.CONF
             CONF.kmip_plugin.keyfile = '/some/path'
             kss.KMIPSecretStore(CONF)
-            self.assertEqual(len(m.mock_calls), 1)
+            self.assertEqual(1, len(m.mock_calls))
