@@ -128,14 +128,12 @@ class WhenPerformingPrivateOperations(utils.BaseTestCase,
                           'between the expected and test dicts')
 
 
-class BaseCertificateRequestsTestCase(utils.BaseTestCase):
+class BaseCertificateRequestsTestCase(database_utils.RepositoryTestCase):
     """Base Certificate Case Test function """
 
     def setUp(self):
         super(BaseCertificateRequestsTestCase, self).setUp()
 
-        database_utils.setup_in_memory_db()
-
         self.external_project_id = "56789"
         self.project = res.get_or_create_project(self.external_project_id)
         project_repo.save(self.project)
@@ -189,7 +187,7 @@ class BaseCertificateRequestsTestCase(utils.BaseTestCase):
             self.ca_id)
 
         self.global_pref_ca = models.PreferredCertificateAuthority(
-            1,
+            self.project.id,
             self.ca_id)
 
         # data for stored key cases
@@ -278,7 +276,6 @@ class BaseCertificateRequestsTestCase(utils.BaseTestCase):
 
     def tearDown(self):
         super(BaseCertificateRequestsTestCase, self).tearDown()
-        database_utils.in_memory_cleanup()
         self.cert_plugin_patcher.stop()
         self.save_plugin_meta_patcher.stop()
         self.get_plugin_meta_patcher.stop()
@@ -539,11 +536,11 @@ class WhenIssuingCertificateRequests(BaseCertificateRequestsTestCase):
         key_pem = crypto.dump_privatekey(
             crypto.FILETYPE_PEM,
             pkey,
-            passphrase=passphrase
+            passphrase=passphrase.encode('utf-8')
         )
         self.private_key_value = base64.b64encode(key_pem)
         self.public_key_value = "public_key"
-        self.passphrase_value = base64.b64encode(passphrase)
+        self.passphrase_value = base64.b64encode(passphrase.encode('utf-8'))
         self.store_plugin.get_secret.side_effect = self.stored_key_side_effect
         self._test_should_return_waiting_for_ca(
             cert_res.issue_certificate_request)
@@ -569,7 +566,7 @@ class WhenIssuingCertificateRequests(BaseCertificateRequestsTestCase):
         self.private_key_value = base64.b64encode(private_key_pem)
         public_key_pem = public_key.exportKey()
         self.public_key_value = base64.b64encode(public_key_pem)
-        self.passphrase_value = base64.b64encode(passphrase)
+        self.passphrase_value = base64.b64encode(passphrase.encode('utf-8'))
 
         self.store_plugin.get_secret.side_effect = self.stored_key_side_effect
         self._test_should_return_waiting_for_ca(
@@ -833,7 +830,7 @@ class WhenCheckingCertificateRequests(BaseCertificateRequestsTestCase):
         )
 
 
-class WhenCreatingSubordinateCAs(utils.BaseTestCase):
+class WhenCreatingSubordinateCAs(database_utils.RepositoryTestCase):
     """Tests the 'create_subordinate_ca()' function."""
 
     def setUp(self):
