@@ -34,8 +34,9 @@ class InitializeDatabaseMixin(object):
         # Force a refresh of the singleton plugin manager for each test.
         manager._PLUGIN_MANAGER = None
         manager.CONF.set_override('enabled_crypto_plugins',
-                                  'simple_crypto',
-                                  group='crypto')
+                                  ['simple_crypto'],
+                                  group='crypto',
+                                  enforce_type=True)
 
         self.project_id1 = uuid.uuid4().hex
         self.project_id2 = uuid.uuid4().hex
@@ -228,9 +229,10 @@ class WhenUsingKeystoneEventConsumerProcessMethod(
         self.assertEqual(secret.id, db_secrets[0].id)
 
         # Get secret_store_metadata for related secret
-        self.assertTrue(len(db_secrets[0].secret_store_metadata) > 0)
+        self.assertGreater(len(db_secrets[0].secret_store_metadata), 0)
 
-        secret_metadata_id = db_secrets[0].secret_store_metadata.values()[0].id
+        secret_metadata_id = list(db_secrets[0].
+                                  secret_store_metadata.values())[0].id
         self.assertIsNotNone(secret_metadata_id)
 
         # Get db entry for secret_store_metadata by id to make sure its
